@@ -10,11 +10,13 @@ use Mojo::SQLite::Database;
 use Mojo::SQLite::Migrations;
 use Mojo::SQLite::PubSub;
 use Scalar::Util 'weaken';
+use SQL::Abstract;
 use URI;
 use URI::db;
 
-our $VERSION = '1.004';
+our $VERSION = '2.000';
 
+has abstract => sub { SQL::Abstract->new(quote_char => '"') };
 has 'auto_migrate';
 has database_class  => 'Mojo::SQLite::Database';
 has dsn             => sub { _url_from_file(shift->_tempfile)->dbi_dsn };
@@ -141,8 +143,16 @@ Mojo::SQLite - A tiny Mojolicious wrapper for SQLite
   # Use migrations to drop and recreate the table
   $sql->migrations->migrate(0)->migrate;
 
-  # Insert a few rows
+  # Get a database handle from the cache for multiple queries
   my $db = $sql->db;
+
+  # Use SQL::Abstract to generate simple CRUD queries for you
+  $db->insert('names', {name => 'Isabel'});
+  say $db->select('names', ['id'], {name => 'Isabel'})->hash->{id};
+  $db->update('names', {name => 'Bel'}, {name => 'Isabel'});
+  $db->delete('names', {name => 'Bel'});
+
+  # Insert a few rows
   $db->query('insert into names (name) values (?)', 'Sara');
   $db->query('insert into names (name) values (?)', 'Stefan');
 
@@ -239,6 +249,13 @@ L<additional temporary files|https://www.sqlite.org/tempfiles.html> safely.
   my $tempfile = catfile $tempdir, 'test.db';
   my $sql = Mojo::SQLite->new->from_filename($tempfile);
 
+=head1 EXAMPLES
+
+This distribution also contains a well-structured example
+L<blog application|https://github.com/kraih/mojo-pg/tree/master/examples/blog>
+you can use for inspiration. This application shows how to apply the MVC design
+pattern in practice.
+
 =head1 EVENTS
 
 L<Mojo::SQLite> inherits all events from L<Mojo::EventEmitter> and can emit the
@@ -257,6 +274,16 @@ Emitted when a new database connection has been established.
 
 L<Mojo::SQLite> implements the following attributes.
 
+=head2 abstract
+
+  my $abstract = $sql->abstract;
+  $sql         = $sql->abstract(SQL::Abstract->new);
+
+L<SQL::Abstract> object used to generate CRUD queries for
+L<Mojo::SQLite::Database>.
+
+  my($stmt, @bind) = $sql->abstract->select('names');
+
 =head2 auto_migrate
 
   my $bool = $sql->auto_migrate;
@@ -349,7 +376,7 @@ problems like connection timeouts gracefully by holding on to it only for short
 amounts of time.
 
   # Add up all the money
-  say $sql->db->query('select * from accounts')
+  say $sql->db->select('accounts')
     ->hashes->reduce(sub { $a->{money} + $b->{money} });
 
 =head2 from_filename
@@ -423,6 +450,15 @@ string, it will be parsed and applied to L</"options">.
   $sql->from_string(Mojo::URL->new->scheme('sqlite')->path($filename)->query(sqlite_see_if_its_a_number => 1));
   $sql->from_string(URI::file->new($filename)->Mojo::Base::tap(query_form => {PrintError => 1}));
 
+=head1 DEBUGGING
+
+You can set the C<DBI_TRACE> environment variable to get some advanced
+diagnostics information printed by L<DBI>.
+
+  DBI_TRACE=1
+  DBI_TRACE=15
+  DBI_TRACE=SQL
+
 =head1 REFERENCE
 
 This is the class hierarchy of the L<Mojo::SQLite> distribution.
